<?php

namespace Litecms\Crypto\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Crypto\Models\Crypto;

class CryptoPolicy
{

    /**
     * Determine if the given user can view the crypto.
     *
     * @param UserPolicy $user
     * @param Crypto $crypto
     *
     * @return bool
     */
    public function view(UserPolicy $user, Crypto $crypto)
    {
        if ($user->canDo('crypto.crypto.view') && $user->isAdmin()) {
            return true;
        }

        return $crypto->user_id == user_id() && $crypto->user_type == user_type();
    }

    /**
     * Determine if the given user can create a crypto.
     *
     * @param UserPolicy $user
     * @param Crypto $crypto
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('crypto.crypto.create');
    }

    /**
     * Determine if the given user can update the given crypto.
     *
     * @param UserPolicy $user
     * @param Crypto $crypto
     *
     * @return bool
     */
    public function update(UserPolicy $user, Crypto $crypto)
    {
        if ($user->canDo('crypto.crypto.edit') && $user->isAdmin()) {
            return true;
        }

        return $crypto->user_id == user_id() && $crypto->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given crypto.
     *
     * @param UserPolicy $user
     * @param Crypto $crypto
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Crypto $crypto)
    {
        return $crypto->user_id == user_id() && $crypto->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given crypto.
     *
     * @param UserPolicy $user
     * @param Crypto $crypto
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Crypto $crypto)
    {
        if ($user->canDo('crypto.crypto.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given crypto.
     *
     * @param UserPolicy $user
     * @param Crypto $crypto
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Crypto $crypto)
    {
        if ($user->canDo('crypto.crypto.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
